﻿// Developer Express Code Central Example:
// How to load an external Window/UserControl into a DocumentPanel
// 
// You can define a Window, Page or UserControl in external XAML files and then,
// with DXDocking, load their contents into DocumentPanel objects.
// 
// This example
// demonstrates how to load an external Window and UserControl into
// DocumentPanels.
// 
// In the example three approaches are demonstrated:
// 
// 1) The
// contents of MyWindow.xaml is loaded into a DocumentPanel at design time (in
// XAML) via the DocumentPanel.Content property. The Content property accepts a Uri
// object, which must refer to a XAML file defining a Window, Page or
// UserControl.
// 
// dxdo:DocumentPanel x:Name="docPanel2" Caption="Panel 2"
// Content="{dxdo:RelativeUri UriString=CustomWindows\\MyWindow.xaml}"
// 
// 
// 2) The
// DocumentPanel.Content property is set with a Uri object at
// runtime:
// 
// docPanel1.Content = new Uri(@"CustomWindows\MyWindow1.xaml",
// UriKind.Relative);
// 
// 
// 3) The DockLayoutManager.DockController.AddDocumentPanel
// method creates a new DocumentPanel object and loads the contents of an external
// XAML file into the created panel. panel1 =
// dockLayoutManager1.DockController.AddDocumentPanel(documentGroup1,  new
// Uri(@"CustomWindows\UserControl1.xaml", UriKind.Relative));
// panel1.Caption =
// "Document " + (ctr++).ToString();
// 
// 
// In the example, the XAML file defines a
// UserControl object. The loaded UserControl is accessed via the DocumentPanel's
// Control property and then a method on the UserControl is
// invoked.
// 
// //...
// (panel1.Control as
// UserControl1).SetDataContext(imageInfo);
// 
// 
// You can see this in action by
// clicking the "Set DataContext for UserControl" button in the example.
// 
// You can find sample updates and versions for different programming languages here:
// http://www.devexpress.com/example=E2410

using System.Reflection;
using System.Resources;
using System.Runtime.CompilerServices;
using System.Runtime.InteropServices;
using System.Windows;

// General Information about an assembly is controlled through the following 
// set of attributes. Change these attribute values to modify the information
// associated with an assembly.
[assembly: AssemblyTitle("TestProject")]
[assembly: AssemblyDescription("")]
[assembly: AssemblyConfiguration("")]
[assembly: AssemblyCompany("DSCore")]
[assembly: AssemblyProduct("TestProject")]
[assembly: AssemblyCopyright("Copyright © DSCore 2017")]
[assembly: AssemblyTrademark("")]
[assembly: AssemblyCulture("")]

// Setting ComVisible to false makes the types in this assembly not visible 
// to COM components.  If you need to access a type in this assembly from 
// COM, set the ComVisible attribute to true on that type.
[assembly: ComVisible(false)]

//In order to begin building localizable applications, set 
//<UICulture>CultureYouAreCodingWith</UICulture> in your .csproj file
//inside a <PropertyGroup>.  For example, if you are using US english
//in your source files, set the <UICulture> to en-US.  Then uncomment
//the NeutralResourceLanguage attribute below.  Update the "en-US" in
//the line below to match the UICulture setting in the project file.

//[assembly: NeutralResourcesLanguage("en-US", UltimateResourceFallbackLocation.Satellite)]


[assembly: ThemeInfo(
    ResourceDictionaryLocation.None, //where theme specific resource dictionaries are located
    //(used if a resource is not found in the page, 
    // or application resource dictionaries)
    ResourceDictionaryLocation.SourceAssembly //where the generic resource dictionary is located
    //(used if a resource is not found in the page, 
    // app, or any theme specific resource dictionaries)
)]


// Version information for an assembly consists of the following four values:
//
//      Major Version
//      Minor Version 
//      Build Number
//      Revision
//
// You can specify all the values or you can default the Build and Revision Numbers 
// by using the '*' as shown below:
// [assembly: AssemblyVersion("1.0.*")]
[assembly: AssemblyVersion("1.0.0.0")]
[assembly: AssemblyFileVersion("1.0.0.0")]
[assembly: GuidAttribute("05B16094-C5C1-40D5-BE7B-F85D9E10AA63")]
